#
# spec file for package byobu
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           byobu
Version:        5.133
Release:        2.14
Summary:        Enhanced profile and configuration utilities for GNU Screen and tmux
License:        GPL-3.0-only
Group:          System/Console
URL:            https://byobu.org/
Source:         https://launchpad.net/%{name}/trunk/%{version}/+download/%{name}_%{version}.orig.tar.gz
Source1:        https://launchpad.net/%{name}/trunk/%{version}/+download/..-%{name}_%{version}.orig.tar.gz.asc#/%{name}_%{version}.orig.tar.gz.asc
Source2:        %{name}.keyring
# For /usr/share/dbus-1/services/ ownership.
BuildRequires:  dbus-1-devel
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
# For env in desktop-file
Requires:       coreutils
Requires:       gawk
Requires:       gettext-runtime
Requires:       net-tools
Requires:       python3-newt
Requires:       snack
Recommends:     pastebinit
Recommends:     sensible-utils
Recommends:     tmux
Suggests:       %{name}-doc
Suggests:       screen
Suggests:       wireless-tools
BuildArch:      noarch
%{perl_requires}

%package doc
Summary:        Documentation files for byobu
Group:          Documentation/Other
Requires:       %{name}

%description
Byobu includes an enhanced profiles, convenient keybindings,
configuration utilities, and toggle-able system status
notifications for both the GNU Screen window manager and tmux
terminal multiplexer.

%description doc
Help files and changelog for %{name}.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_docdir}/
mv -f %{buildroot}%{_datadir}/doc/%{name}/ %{buildroot}%{_docdir}/%{name}/

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
ln -s ../../../../%{name}/pixmaps/%{name}.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

mkdir -p %{buildroot}%{_datadir}/applications/
rm %{buildroot}%{_datadir}/%{name}/desktop/byobu.desktop
mv %{buildroot}%{_datadir}/%{name}/desktop/byobu.desktop.old %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file -G "Screen Profiles" -r %{name} System TerminalEmulator
%fdupes %{buildroot}%{_mandir}/

sed -i 's,%{_bindir}/env python3,%{_bindir}/python3,' %{buildroot}%{_prefix}/lib/byobu/include/*.py

%files
%license COPYING
%doc README.md
%config %{_sysconfdir}/profile.d/Z97-%{name}.*sh
%dir %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/*
%{_bindir}/*
%{_prefix}/lib/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/*.1%{?ext_man}
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/dbus-1/services/*%{name}.service
%if 0%{?suse_version} == 1315
%exclude %{_docdir}/%{name}/help.*.txt
%endif

%files doc
%doc ChangeLog
%{_docdir}/%{name}/help.*.txt

%changelog
* Sat Aug 29 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Fix build after libexec change in distribution
* Sun Mar 29 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 5.133:
  * debian/docs: Closes: #951455
  - fix FTBFS on README
  byobu (5.132-0ubuntu1) focal; urgency=medium
  * debian/control, debian/rules:
  - pep8 binary is gone from Debian, disable for now
* Sun Feb 16 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 5.131
  * debian/control: Closes: #949941
  - build-depend on python3-pep8, rather than pep8 transitional package
  * usr/lib/byobu/disk:
  - change disk status to white on darker magenta/purple, helps with
    readability on some terminals
  * usr/lib/byobu/include/select-session.py: LP: #1750430
  - commit edeae41 fixed the excessive creation of sessions by not
    creating different sessions. This commit adjust the behavior in a way
    that having .reuse-sessions enabled tmux will properly attach and remove
    sessions when dettaching and will also kill the last session available
  - When more than two sessions exist, tmux asks which session to use
  * usr/share/byobu/keybindings/f-keys.tmux: LP: #1861555
  - Update usage of tmux swap-window so that focus stays with the
    original window.
* Tue Feb  4 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.130
  * usr/lib/byobu/logo:
  - add Raspbian colors / logo
  * usr/lib/byobu/include/select-session.py:
  - Force UTF-8 when attaching in `select-session.py`
  * debian/rules:
  - ignore new pep8 rules around hard tabs and whitespaces, related
    to bug 1843729
  * AUTHORS, CONTRIBUTING, NEWS, README, README.md:
  - Flatten these files into a single README.md
  - Minor updates in the process
- Remove unnecessary python-devel BuildRequires.
- Replace shebang for two env-using scripts.
* Sat Aug 24 2019 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to 5.129
  + see https://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Tue Jan 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Require python3-newt, fixes bsc#1121502
* Mon Aug 13 2018 tejas.guruswamy@opensuse.org
- update to 5.127. key changes:
  * usr/share/byobu/profiles/bashrc:
  - Googley PS1 for non-Ubuntu distros
  * usr/lib/byobu/include/shutil, usr/lib/byobu/Makefile.am,
    usr/lib/byobu/rcs_cost, usr/share/byobu/status/status,
    usr/share/man/man1/byobu.1,
    usr/lib/byobu/ec2_cost,
    usr/lib/byobu/include/ec2instancespricing.py,
    usr/lib/byobu/include/Makefile.am, usr/lib/byobu/include/shutil,
    usr/lib/byobu/Makefile.am, usr/share/byobu/status/status,
    usr/share/man/man1/byobu.1,
  * usr/bin/byobu-janitor.in:
  - deprecate unmaintained ec2/rcs pricing functionality
  - this never really worked well, and these prices are constantly changing
  - clear out stale status cache
  * debian/control, usr/lib/byobu/ip_address, usr/lib/byobu/network,
    usr/share/man/man1/wifi-status.1: LP: #1748956
  - switch entirely to iproute2, away from net-tools and ifconfig
  - only remaining ifconfig is fall-back logic, in case /sbin/ip is
    not found
  * usr/bin/byobu-select-profile.in, usr/share/man/man1/byobu-select-
    profile.1: LP: #1717746
  - deprecate interactive mode for byobu-select-profile
  * usr/lib/byobu/include/toggle-utf8.in: LP: #1696546
  - try to support zsh and other shells in addition to bash
  * usr/share/byobu/profiles/bashrc:
  - fix missing bash 256 ps1 colors
  * usr/lib/byobu/include/constants, usr/share/byobu/keybindings/f-
    keys.screen, usr/share/byobu/keybindings/f-keys.tmux:
  - create a $BYOBU_EDITOR variable, using "sensible-editor" if found
    (it will be on Debian/Ubuntu systems), or $EDITOR if not, and falling
    back to "vim" in the case where none are found
  - use $BYOBU_EDITOR with Shift-F7 to open the printscreen buffer in
    a new window;  this fixes a bug on some distros where $EDITOR might
    be undefined
  * usr/lib/byobu/session:
  - don't count sessions that start with _ BUG: #892489
  * usr/lib/byobu/updates_available:
  - Fix rare race condition for update_needed and cache file (#26)
  - https://github.com/dustinkirkland/byobu/pull/26
  * byobu.desktop:
  - give some hints for GNOME Shell to correctly match byobu desktop file
    (LP: #1718482); partial fix, not entirely working yet
* Sat Mar 31 2018 sebix+novell.com@sebix.at
- update to 5.125:
  * usr/share/byobu/profiles/dircolors: LP: #1752352
  - fix blinking symlinks
  * usr/lib/byobu/include/select-session.py:
  - Fix cull_zombies() so that we properly cull zombies of sessions that
    have non-numeric session names
  - Allow the dynamic session-creation behaviour to be disabled by
    creating ~/.byobu/.reuse-session
  * debian/control:
  - need sensible-utils
* Mon Jan  8 2018 tejas.guruswamy@opensuse.org
- update to 5.124
  * usr/bin/wifi-status:
  - add a speedometer split
  * debian/control, usr/bin/wifi-status,
    usr/share/byobu/profiles/bashrc:
  - kill the double bracket; doesn't always print nicely
  * === added directory snap, snap/snapcraft.yaml:
  - initial crack at snap packaging
  * usr/lib/byobu/include/select-session.py:
  - Fix culling sessions with named groups (#25)
  - https://github.com/dustinkirkland/byobu/pull/25
  * usr/bin/purge-old-kernels:
  - make sure we pass through the -f|-y apt options
  * Build-depend on dh-python.
  * Drop the alternative python2 dependencies. LP: #1735348.
* Mon Sep 25 2017 sebix+novell.com@sebix.at
- update to 5.123
  * po/es.po:
  - fix typos and errors in the spanish translation (#21)
  * usr/bin/wifi-status:
  - use iw and ip rather than ifconfig and iwconfig, which are deprecated (#24)
  * usr/bin/byobu.in:
  - add support for a BYOBU_ALT_TITLE variable, which enables users to
    set an alternate window title for their byobu session
  * usr/bin/byobu-ctrl-a.in: LP: #1710780, #23
  - set prefix2 to F12 in screen-compat ctrl-a mode
* Thu Aug 31 2017 sebix+novell.com@sebix.at
- upgrade to 5.122:
  * usr/lib/byobu/include/config.py.in, usr/lib/byobu/include/select-
    session.py: LP: #1711026
  - Byobu currently FTBFS on artful during pep8 verification due to
    the newly introduced E722 - ie. a 'try:/except:' block with a
    bare except that should be replaced by a 'try:except Exception:' block.
- upgrade to 5.121:
  * usr/bin/wifi-status:
  - timestamp the pings
  * autogen.sh, .bzrignore, configure.ac:
  - modernize autoconf, add .bzrignore
  - my intent is to add autogen.sh as next step as seems you currently
    produce release tarballs manually, so it contains random unneeded
    crap like autom4te.cache
- upgrade to 5.120:
  * usr/lib/byobu/include/shutil:
  - revert the last two changes;  that was a wild goose chase
* Sun Jul 30 2017 sebix+novell.com@sebix.at
- split documentation package
- fix desktop-file
- upgrade to 5.119:
  * usr/lib/byobu/include/shutil:
  - fix regression in distro detection
- upgrade to 5.118:
  * usr/lib/byobu/include/shutil:
  - use /etc/lsb-release, if it exists
    fixes detection of Linux Mint
* Mon May 15 2017 tejas.guruswamy@opensuse.org
- Update to version 5.117 (key changes since 5.108):
  * usr/share/byobu/profiles/tmux:
  - save 100K lines of scrollback, rather than 10K, which I find gets
    eclipsed too often when you actually need it
  * usr/bin/byobu.in, usr/share/byobu/profiles/tmux:
  - use screen-256color if possible, for both screen and tmux
  - allow the user to override our term choices, by setting
    BYOBU_TERM, BYOBU_DEFAULT_TERM and/or BYOBU_COLOR_TERM
  + see also https://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
- Update package requirements and recommends to include perl, gettext, net-tools
* Sun Jul  3 2016 sor.alexei@meowr.ru
- Update to version 5.108 (changes since 5.104):
  * usr/share/man/man1/byobu.1:
  - Update examples.
  * usr/lib/byobu/swap, usr/share/man/man1/byobu.1:
  - Switch swap to black on green, white on green was unreadable.
  * usr/bin/byobu-ctrl-a.in:
  - Silence stderr.
  * usr/share/byobu/profiles/bashrc:
  - Fix colour comment.
  * usr/bin/byobu-janitor.in:
  - No longer default to enabling ec2 status (lp#1564320).
  - Institute better timeouts for metadata wgets (lp#1564320).
  * usr/bin/byobu-select-session.in:
  - Exec the select-session command, to keep from having an sh
    hanging around (lp#1555446).
  * usr/bin/manifest:
  - Remove http, breaks pastebinit.
  - Fix manifest URL.
  * usr/bin/wifi-status:
  - Use tmux target pane.
  * usr/lib/byobu/battery:
  - Use `POWER_SUPPLY_CAPACITY` for battery if available and
    neither POWER_SUPPLY_ENERGY_NOW nor POWER_SUPPLY_CHARGE_NOW
    are available (important for summing multiple batteries).
  * usr/lib/byobu/include/tmux-send-command-to-all-panes:
  - Fix breakage on sending command to all panes.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 5.104.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 5.99:
  * usr/share/byobu/pixmaps/byobu.svg:
  - Clean up vector image from Nobuto Murata.
  * configure.ac, debian/install, debian/postinst, debian/postrm,
    etc/profile.d/Makefile.am, usr/share/byobu/profiles/Makefile.am,
    usr/share/byobu/profiles/Z97-byobu.sh.in => etc/profile.d/Z97-
    byobu.sh.in:
  - Fix some recent regressions on byobu auto launching.
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 5.98:
  * usr/bin/vigpg:
  - Specify stdin for input file.
  * usr/bin/vigpg:
  - Get vigpg working with the new release of gpg in 15.10.
  - Clean up encrypted copies of the file.
  * usr/share/applications/byobu.desktop:
  - Use byobu icon rather than gnome-terminal (lp#1503418).
  * usr/lib/byobu/include/config.py.in:
  - Fix help for openSUSE.
* Sun Sep 27 2015 sor.alexei@meowr.ru
- Update to 5.97 (changes since 5.94):
  * usr/lib/byobu/battery:
  - Sum together all batteries.
  * usr/bin/byobu.in:
  - Ensure we start tmux with unicode support (lp#1268072).
  - Respect user's custom default-command and/or default-shell in
    the first window launched (lp#1369783).
  * usr/bin/byobu.in, usr/share/man/man1/byobu.1:
  - byobu -h|--help enters manpage, place this code with
  - v|--version (lp#1483394).
  * usr/bin/byobu-shell.in:
  - Find the motd (lp#1458941).
  * usr/share/byobu/keybindings/f-keys.tmux.disable:
  - Ensure that we source user's keybindings (lp#1453037).
  * experimental/byobu-classroom, usr/bin/byobu-ctrl-a.in,
    usr/bin/byobu-disable-prompt.in, usr/bin/byobu-janitor.in,
    usr/bin/byobu-launcher-uninstall.in, usr/bin/byobu-quiet.in,
    usr/bin/byobu-silent.in, usr/bin/byobu-status.in,
    usr/lib/byobu/include/constants,
    usr/share/byobu/keybindings/f-keys.screen:
  - Create BYOBU_SED_INLINE variable, to handle inline sed's,
    using --follow-symlinks when possible (not always available)
    (lp#1068580).
  * usr/lib/byobu/logo:
  - Fix minor logic typo (reversed logic).
  * usr/bin/byobu-launcher.in:
  - Add some helpful information about nested sessions (lp#1338260).
  - Fix byobu autolaunch for TERM=screen-256color users (lp#1338260).
  * usr/lib/byobu/include/constants:
  - Fix check for sed's follow-symlinks feature.
  * configure.ac, debian/install, debian/postinst, debian/postrm,
    etc/profile.d/Makefile.am, etc/profile.d/Z97-byobu.sh.in =>
    usr/share/byobu/profiles/Z97-byobu.sh.in, usr/bin/byobu.in,
    usr/bin/byobu-launcher-install.in,
    usr/lib/byobu/include/config.py.in,
    usr/share/byobu/profiles/Makefile.am:
  - Fix some discrepancies between Z97- and Z98-.
- Move documentation to a proper directory.
- Add tarball signing.
- Spec cleanup.
* Wed Aug 12 2015 tejas.guruswamy@opensuse.org
- Update to 5.94
  + see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Fri Nov 14 2014 brian@aljex.com
- update to 5.87
  see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
  removed byobu-remove_shebang_from_profile_sourced.patch, upstream fixeda
  allow building on older targets back to SL 10.0
* Fri Jul 26 2013 pascal.bleser@opensuse.org
- update to 5.47:
  + see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Sun Jun 30 2013 crrodriguez@opensuse.org
- version 5.43
  + see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Wed Apr  3 2013 tejas.guruswamy@opensuse.org
- Fix unecessary shebang in Z97-byobu.sh (patch from pbleser)
* Wed Apr  3 2013 tejas.guruswamy@opensuse.org
- Update to 5.35
  + see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Tue Jan 22 2013 tejas.guruswamy@opensuse.org
- Update to 5.29
  + see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Sun Dec 16 2012 tejas.guruswamy@opensuse.org
- Update to 5.22
  + see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Fri Jul 27 2012 tejas.guruswamy@opensuse.org
- Update to 5.21
  + see http://bazaar.launchpad.net/~kirkland/byobu/trunk/view/head:/debian/changelog
* Fri Jan 20 2012 tejas.guruswamy@opensuse.org
- Update to 5.5
* Tue Dec 13 2011 tejas.guruswamy@opensuse.org
- Update to 4.54
* Tue Sep  6 2011 tejas.guruswamy@opensuse.org
- Add fix for lp#842113 apport doesn't behave as intended
* Mon Sep  5 2011 tejas.guruswamy@opensuse.org
- Update to 4.32
    + silence message that some users found noisy
    + fix a suite of support issues around launching byobu under sudo, where
    files/dirs would be created under the $SUDO_USER's $HOME, but would be
    owned by root + save a fork
    + fix bold color printing
    + deprecate backticks file, no longer needed
    + fix breakage when $TMUX is undefined
    + go bold on window activity
    + clean up and make window colorings more consistent
    + speed up disabled status runs
    + support tmux status, using a cached print mechanism and a list of
    + left and right status items
    + drop the failed byobu-statusd experiment and its byobu-status-print
    + helper
    + add a PCT constant, required to support both screen and tmux
    + fix a bug/typo in shutil (should be /proc/uptime)
    + separate status cache between screen and tmux (different formatting)
    + make byobu-status-tmux support screen
    + PCT="%%%%" for both
    + update backticks and caption/hardstatus
    + fix default status
    + drop backticks and double printing of date/time in tmux
    + transition to the new, faster, less-resource intensive status
    + gathering method
    + migrate to toggling on/off the list of status items
    + fix initial seeding of status config
    + drop experimental code, no longer necessary
    + test non-zero cache file
    + combine mem_* to memory
    + decrease raid status frequency
    + add trailing space to logo
    + make network calculations drastically cheaper, by using status_freq
    + rather than a file stat
    + ensure that byobu-janitor runs on reload
    + must separate run dirs for tmux/screen run status scripts;
    + otherwise, calculated rates are off
    + fix wireless utf8 icon bug, default to utf8 for tmux
    + fix tmux color rendering
    + fix underscore, italics, hidden
    + ensure that the cache dir gets created
    + get 256 colors working in tmux
    + add .zZ symbol for powernap state, per feedback at LinuxConNA in
    + Vancouver
    + fix flag path; simplify coloring
    + add session selection support for tmux
    + flatten bold/dim/bright modifiers when in 8-color mode
    + fix bold printing
    + check exist status of session listing
    + fix stray directory creation
    + fall back to the tmux tmpdir
* Sat Aug 13 2011 tejas.guruswamy@opensuse.org
- Update to 4.29
* Mon Sep 27 2010 pascal.bleser@opensuse.org
- initial package (3.5)
